Derive Macros
- Index
- Derives the
Indextrait for a struct where each field is itself anIndex. - Shallow
Clone - Derives the
ShallowClonetrait for a struct where each field is itself aShallowClone.
Index trait for a struct where each field is itself an Index.ShallowClone trait for a struct where each field is itself a ShallowClone.